@@ -567,6 +567,81 @@ using-multipliers-zone-and-or-window.html
         for room in rooms_2ds:
             self.add_room_2d(room)
 
+    def reset_room_2d_boundaries(
+            self, polygons, identifiers=None, display_names=None,
+            floor_to_ceiling_heights=None, tolerance=0.01):
+        """Rebuild the Room2Ds of the Story using boundary Polygons.
+
+        All existing properties of segments along the boundary polygons will be
+        preserved, including all window geometries. By default, the largest room
+        that is identified within each of the boundary polygons will determine the
+        extension properties of the resulting Room2D.
+
+        It is recommended that the Room2Ds be aligned to the boundaries of the
+        polygon and duplicate vertices be removed before using this method.
+
+        Args:
+            polygons: A list of ladybug_geometry Polygon2D, which will become
+                the new boundaries of the Story's Room2Ds. Note that it is
+                acceptable to include hole polygons in this list and they will
+                automatically be sensed by their relationship to the other
+                polygons.
+            identifiers: An optional list of text that align with the polygons
+                and will dictate the identifiers of the Story's Rooms. If this
+                matches an existing Room2D inside of the polygon, the existing
+                Room2D will be used to set the extension properties of the output
+                Room2D. If None, the identifier and extension properties of the
+                output Room2D will be those of the largest Room2D found inside
+                of the polygon. (Default: None).
+            display_names: An optional list of text that align with the
+                polygons and will dictate the display_names of the Story's Rooms.
+                If None, the display_name will be taken from the
+                largest existing Room2D inside the polygon or the existing
+                Room2D matching the identifier above. (Default: None).
+            floor_to_ceiling_heights: An optional list of numbers that align with the
+                polygons and will dictate the the floor-to-ceiling heights of the
+                resulting Room2Ds. If None, it will be the maximum of the Room2Ds
+                that are found inside each of the polygon, which ensures
+                that all window geometries are included in the output. If specified
+                and it is lower than the maximum Room2D height, any detailed
+                windows will be automatically trimmed to accommodate the new
+                floor-to-ceiling height. (Default: None).
+            tolerance: The minimum distance between a vertex and the polygon
+                boundary at which point the vertex is considered to lie on the
+                polygon. (Default: 0.01, suitable for objects in meters).
+        """
+        # set defaults for identifiers and display_names
+        if identifiers is None:
+            identifiers = [None] * len(polygons)
+        if display_names is None:
+            display_names = [None] * len(polygons)
+        if floor_to_ceiling_heights is None:
+            floor_to_ceiling_heights = [None] * len(polygons)
+        # sort the polygons so they can be correctly interpreted as holes
+        p_areas = [p.area for p in polygons]
+        sort_ind = [i for _, i in sorted(zip(p_areas, range(len(p_areas))))]
+        sort_ind.reverse()
+        sort_poly = [polygons[i] for i in sort_ind]
+        sort_ids = [identifiers[i] for i in sort_ind]
+        sort_names = [display_names[i] for i in sort_ind]
+        sort_ftcs = [floor_to_ceiling_heights[i] for i in sort_ind]
+        # loop through the polygons and make the Room2Ds
+        new_room_2ds = []
+        skip_i = []  # list to track hole polygons to be skipped
+        zip_obj = zip(sort_poly, sort_ids, sort_names, sort_ftcs)
+        for i, (poly, r_id, r_nm, ftc) in enumerate(zip_obj):
+            if i in skip_i:
+                continue
+            holes = []
+            for j, o_poly in enumerate(sort_poly[i + 1:]):
+                if poly.is_polygon_inside(o_poly):
+                    holes.append(o_poly)
+                    skip_i.append(i + j + 1)
+            new_room = Room2D.join_by_boundary(
+                self._room_2ds, poly, holes, ftc, r_id, r_nm, tolerance=tolerance)
+            new_room_2ds.append(new_room)
+        self._room_2ds = tuple(new_room_2ds)
+
     def align_room_2ds(self, line_ray, distance):
         """Move Room2D vertices within a given distance of a line to be on that line.
 
@@ -657,12 +732,14 @@ using-multipliers-zone-and-or-window.html
             tolerance: The minimum difference between the coordinate values of two
                 faces at which they can be considered adjacent. Default: 0.01,
                 suitable for objects in meters.
-            preserve_wall_props: Boolean to note whether exterior window parameters,
-                shading parameters and boundary conditions should be preserved
-                as vertices are removed. Doing so will take longer and Surface
-                boundary conditions will still likely be incorrect but they can
-                usually be repaired using reset_adjacency followed by
-                solve_adjacency. (Default: True).
+            preserve_wall_props: Boolean to note whether existing window parameters
+                and Ground boundary conditions should be preserved as vertices are
+                removed. If False, all boundary conditions are replaced with Outdoors,
+                all window parameters are erased, and this method will execute quickly.
+                If True, an attempt will be made to merge window parameters together
+                across colinear segments, translating simple window parameters to
+                rectangular ones if necessary. Also, existing Ground boundary
+                conditions will be kept. (Default: True).
             delete_degenerate: Boolean to note whether degenerate Room2Ds (with
                 floor geometries that evaluate to less than 3 vertices at the
                 tolerance) should be deleted from the Story instead of raising
@@ -747,7 +824,7 @@ using-multipliers-zone-and-or-window.html
         self._room_2ds = tuple(new_room_2ds)
         return removed_rooms
 
-    def rebuild_detailed_windows(self, tolerance=0.01):
+    def rebuild_detailed_windows(self, tolerance=0.01, match_adjacency=False):
         """Rebuild all detailed windows such that they are bounded by their parent walls.
 
         This method will also ensure that all interior windows on adjacent wall
@@ -760,6 +837,11 @@ using-multipliers-zone-and-or-window.html
             tolerance: The minimum distance between a vertex and the edge of the
                 wall segment that is considered not touching. (Default: 0.01, suitable
                 for objects in meters).
+            match_adjacency: A boolean to note whether this method should ensure
+                that all interior windows on adjacent wall segments are matched
+                correctly with one another. This is desirable when the existing
+                adjacencies across the model are correct but it can create several
+                unwanted cases when the adjacencies are not correct. (Default: False).
         """
         adj_dict = {}
         for room in self.room_2ds:
@@ -770,7 +852,7 @@ using-multipliers-zone-and-or-window.html
                 if isinstance(w_par, DetailedWindows):
                     new_w_par = w_par.adjust_for_segment(
                         seg, room.floor_to_ceiling_height, tolerance)
-                    if isinstance(bc, Surface):
+                    if match_adjacency and isinstance(bc, Surface):
                         try:
                             adj_seg = bc.boundary_condition_objects[0]
                             new_w_par = adj_dict[adj_seg].flip(seg.length)
